trait NameVec<T>{
// Required methods
fn remove_item<S: NameMember>(&mut self, item: &S) -> bool;
fn add_item(&mut self, name: T);
fn remove_duplicates(&mut self) -> &mut Self;
fn intersection<S>(&mut self, others: &[S])
where S: NameMember + Canonicalization + Clone;
fn difference(&mut self, others: &[T]);
}Expand description
Supporting algorithms on lists of elements and lists of attributes, from the specification.
Required Methods
Sourcefn remove_item<S: NameMember>(&mut self, item: &S) -> bool
fn remove_item<S: NameMember>(&mut self, item: &S) -> bool
Sourcefn remove_duplicates(&mut self) -> &mut Self
fn remove_duplicates(&mut self) -> &mut Self
Sourcefn intersection<S>(&mut self, others: &[S])
fn intersection<S>(&mut self, others: &[S])
Set itself to the set intersection of itself and another list.
Sourcefn difference(&mut self, others: &[T])
fn difference(&mut self, others: &[T])
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl<T> NameVec<T> for Vec<T>
impl<T> NameVec<T> for Vec<T>
Sourcefn remove_item<S: NameMember>(&mut self, item: &S) -> bool
fn remove_item<S: NameMember>(&mut self, item: &S) -> bool
Sourcefn remove_duplicates(&mut self) -> &mut Self
fn remove_duplicates(&mut self) -> &mut Self
Sourcefn intersection<S>(&mut self, others: &[S])
fn intersection<S>(&mut self, others: &[S])
Set itself to the set intersection of itself and another list.
Sourcefn difference(&mut self, others: &[T])
fn difference(&mut self, others: &[T])
Set itself to the set difference of itself and another list.